==> 1.1.1.tar.gz: lib/src/mockup_page_list.dart <==
import 'package:dotup_flutter_mockups/src/mockup_controller.dart';
import 'package:flutter/material.dart';

import 'settings/settings_view.dart';

class MockupPageList extends StatelessWidget {
  const MockupPageList({
    Key? key,
    required this.controller,
    // required this.onPageSelected,
  }) : super(key: key);

  final MockupController controller;
  // final ValueSetter<int> onPageSelected;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text('tob mockups'),
        leading: IconButton(
          onPressed: () {
            controller.hidePageMenu();
          },
          icon: Icon(Icons.close),
        ),
        actions: [
          IconButton(
            icon: const Icon(Icons.settings),
            onPressed: () {
              // Navigate to the settings page. If the user leaves and returns
              // to the app after it has been killed while running in the
              // background, the navigation stack is restored.
              Navigator.restorablePushNamed(context, SettingsView.routeName);
            },
          ),
        ],
      ),
      body: ListView.builder(
        itemCount: controller.pages.length,
        itemBuilder: (context, index) {
          final page = controller.pages[index];
          final enabled = index != controller.currentPageIndex;
          // page.number != controller.currentPage;
          final subtitle = page.subtitle == null ? null : Text(page.subtitle!);
          final trailing = page.icon == null ? null : Icon(page.icon);

          return ListTile(
            title: Text(page.title),
            subtitle: subtitle,
            leading: Text(page.number.toString()),
            trailing: trailing,
            enabled: enabled,
            onTap: () {
              controller.toPage(index);
            },
          );
        },
      ),
    );

    // return Material(
    //   child: PopupMenuButton<MockupPageDescriptor>(
    //     // color: Colors.transparent,
    //     padding: EdgeInsets.zero,
    //     initialValue: pages.first,
    //     onSelected: (value) => print(value),
    //     itemBuilder: (context) => _getMenuItems(context),
    //   ),
    // );
  }

  // List<PopupMenuItem<MockupPageDescriptor>> _getMenuItems(BuildContext context) {
  //   var index = 1;
  //   final style = TextStyle(color: index == currentIndex ? Colors.white : null);

  //   return pages.map((e) {
  //     index++;
  //     return PopupMenuItem(
  //       child: ListTile(
  //         // tileColor: index == currentIndex ? Colors.grey.shade800 : null,
  //         contentPadding: EdgeInsets.symmetric(horizontal: 10),
  //         dense: true,
  //         title: Text(
  //           e.title,
  //           style: style,
  //         ),
  //         leading: Text(
  //           e.number.toString(),
  //           style: style,
  //         ),
  //       ),
  //       value: e,
  //       enabled: index != currentIndex,
  //     );
  //   }).toList();
  // }
}

==> 2.1.1.tar.gz: lib/src/mockup_page_list.dart <==
import 'package:flutter/material.dart';

import 'mockup_controller.dart';
import 'settings/settings_view.dart';

class MockupPageList extends StatelessWidget {
  const MockupPageList({
    Key? key,
    required this.controller,
    // required this.onPageSelected,
  }) : super(key: key);

  final MockupController controller;

  // final ValueSetter<int> onPageSelected;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text(controller.descriptor.title),
        leading: IconButton(
          onPressed: () {
            controller.hidePageMenu();
          },
          icon: Icon(Icons.close),
        ),
        actions: [
          IconButton(
            icon: const Icon(Icons.settings),
            onPressed: () {
              // Navigate to the settings page. If the user leaves and returns
              // to the app after it has been killed while running in the
              // background, the navigation stack is restored.
              Navigator.restorablePushNamed(context, SettingsView.routeName);
            },
          ),
        ],
      ),
      body: ListView.builder(
        itemCount: controller.descriptor.pages.length,
        itemBuilder: (context, index) {
          final page = controller.descriptor.pages[index];
          final enabled = index != controller.currentPageIndex;
          // page.number != controller.currentPage;
          final subtitle = page.subtitle == null ? null : Text(page.subtitle!);
          final trailing = page.icon == null ? null : Icon(page.icon);

          return ListTile(
            title: Text(page.title),
            subtitle: subtitle,
            leading: Text(page.number.toString()),
            trailing: trailing,
            enabled: enabled,
            onTap: () {
              controller.toPage(index);
            },
          );
        },
      ),
    );

    // return Material(
    //   child: PopupMenuButton<MockupPageDescriptor>(
    //     // color: Colors.transparent,
    //     padding: EdgeInsets.zero,
    //     initialValue: pages.first,
    //     onSelected: (value) => print(value),
    //     itemBuilder: (context) => _getMenuItems(context),
    //   ),
    // );
  }

  // List<PopupMenuItem<MockupPageDescriptor>> _getMenuItems(BuildContext context) {
  //   var index = 1;
  //   final style = TextStyle(color: index == currentIndex ? Colors.white : null);

  //   return pages.map((e) {
  //     index++;
  //     return PopupMenuItem(
  //       child: ListTile(
  //         // tileColor: index == currentIndex ? Colors.grey.shade800 : null,
  //         contentPadding: EdgeInsets.symmetric(horizontal: 10),
  //         dense: true,
  //         title: Text(
  //           e.title,
  //           style: style,
  //         ),
  //         leading: Text(
  //           e.number.toString(),
  //           style: style,
  //         ),
  //       ),
  //       value: e,
  //       enabled: index != currentIndex,
  //     );
  //   }).toList();
  // }
}
